@@ -5,6 +5,7 @@
 # Licensed under the terms of the MIT license, see the
 # LICENSE file in the root of the project.
 
+from datetime import datetime, timezone
 from urllib.parse import urljoin
 from urllib3 import disable_warnings
 import json
@@ -81,8 +82,11 @@ class Alfen:
     def properties(self, category=None, ids=None):
         if ids:
             params = {"ids": ids}
-        else:
+        elif category:
             params = {"cat": category}
+        else:
+            raise RuntimeError("Specify a property category or "
+                               "at least one property id.")
 
         response = self._get("/api/prop", params=params)
 
@@ -113,8 +117,15 @@ class Alfen:
                                .format(version))
 
     def whitelist(self, index):
-        return self._get("/api/whitelist",
-                         params={"index": index})['whitelist']
+        for entry in self._get("/api/whitelist",
+                               params={"index": index})['whitelist']:
+            if not entry:
+                continue
+            ed = entry['expiryDate']
+            if ed:
+                ed = datetime.fromtimestamp(ed).replace(tzinfo=timezone.utc)
+            entry['expiryDate'] = ed
+            yield entry
 
     def transactions(self):
         offset = 0
