@@ -8,11 +8,15 @@
 from alfeneve.alfen import Alfen
 from alfeneve.config import load_settings
 from omniconf import config
+from requests.models import HTTPError
 from tabulate import tabulate
 from tzlocal import get_localzone
 import time
 
 
+READABLE_TIMESTAMP = "%Y-%m-%d %H:%M:%S %Z"
+
+
 def categories_workflow(alfen):
     categories = alfen.categories()
     print(tabulate([{"category": c} for c in categories if c], headers="keys"))
@@ -32,7 +36,13 @@ def properties_workflow(alfen):
 
 
 def whitelist_workflow(alfen):
-    whitelist = alfen.whitelist(config("whitelist.index"))
+    local = get_localzone()
+    whitelist = list(alfen.whitelist(config("whitelist.index")))
+    for entry in whitelist:
+        if entry['expiryDate']:
+            entry['expiryDate'] = entry['expiryDate']\
+                .astimezone(local)\
+                .strftime(READABLE_TIMESTAMP)
     print(tabulate([w for w in whitelist if w], headers="keys"))
 
 
@@ -45,7 +55,7 @@ def print_log(log):
     local = get_localzone()
     lid, timestamp, level, filename, linenum, line = log
     dt = timestamp.astimezone(local)
-    dtf = dt.strftime("%Y-%m-%d %H:%M:%S %Z")
+    dtf = dt.strftime(READABLE_TIMESTAMP)
     print("{} {} {:4.4} {:20.20} {}"
           .format(lid, dtf, level, "{}:{}".format(filename, linenum),
                   line))
@@ -82,22 +92,27 @@ def main():
                credentials=(config("alfen.username"),
                             config("alfen.password")),
                verify=config("alfen.certificate")) as alfen:
-        if config("mode") == "properties":
-            properties_workflow(alfen)
-        elif config("mode") == "whitelist":
-            whitelist_workflow(alfen)
-        elif config("mode") == "transactions":
-            transactions_workflow(alfen)
-        elif config("mode") == "logs":
-            if config("logs.follow"):
-                try:
-                    logs_follow_workflow(alfen)
-                except KeyboardInterrupt:
-                    pass
+        try:
+            if config("mode") == "properties":
+                properties_workflow(alfen)
+            elif config("mode") == "whitelist":
+                whitelist_workflow(alfen)
+            elif config("mode") == "transactions":
+                transactions_workflow(alfen)
+            elif config("mode") == "logs":
+                if config("logs.follow"):
+                    try:
+                        logs_follow_workflow(alfen)
+                    except KeyboardInterrupt:
+                        pass
+                else:
+                    logs_workflow(alfen)
             else:
-                logs_workflow(alfen)
-        else:
-            categories_workflow(alfen)
+                categories_workflow(alfen)
+        except RuntimeError as e:
+            print("An unexpected error occurred: {}".format(e))
+        except HTTPError as e:
+            print("An error was received from the API: {}".format(e))
 
 
 if __name__ == "__main__":  # pragma: nocover
