@@ -34,7 +34,7 @@ def load_properties_settings():
     setting("properties.category", default=None,
             help="Category of properties to lookup.")
     setting("properties.ids", _type=separator_sequence(","),
-            help="IDs of individual properties to lookup.")
+            help="IDs of individual properties to lookup, comma separated.")
     setting("properties.verbose", _type=bool, default=False,
             help="Show all values per property.")
 
@@ -66,7 +66,7 @@ def load_settings():
             help="Path to SSL Certificate of the Alfen API endpoint "
                  "to use for SSL verification. By default no "
                  "verification is performed.")
-    setting("mode", _type=enum(VALID_MODES), default="properties",
+    setting("mode", _type=enum(VALID_MODES), default="categories",
             help="Operation mode, must be one of: {}"
                  .format(", ".join(VALID_MODES)))
 
